@@ -1,13 +1,104 @@
-use std::io::Write;
+use std::{fs::File, io::Write, str::FromStr};
 
+use pep508_rs::Requirement;
 use rattler_conda_types::Platform;
 use tempfile::tempdir;
 use typed_path::Utf8TypedPath;
 
 use crate::common::pypi_index::{Database as PyPIDatabase, PyPIPackage};
-use crate::common::{LockFileExt, PixiControl};
+use crate::common::{
+    LockFileExt, PixiControl,
+    package_database::{Package, PackageDatabase},
+};
 use crate::setup_tracing;
-use std::fs::File;
+
+/// This tests if we can resolve pyproject optional dependencies recursively
+/// before when running `pixi list -e all`, this would have not included numpy
+/// we are now explicitly testing that this works
+#[tokio::test]
+async fn pyproject_optional_dependencies_resolve_recursively() {
+    setup_tracing();
+
+    let simple = PyPIDatabase::new()
+        .with(PyPIPackage::new("numpy", "1.0.0"))
+        .with(PyPIPackage::new("sphinx", "1.0.0"))
+        .with(PyPIPackage::new("pytest", "1.0.0"))
+        .into_simple_index()
+        .unwrap();
+
+    let platform = Platform::current();
+    let platform_str = platform.to_string();
+
+    let mut package_db = PackageDatabase::default();
+    package_db.add_package(
+        Package::build("python", "3.11.0")
+            .with_subdir(platform)
+            .finish(),
+    );
+    let channel = package_db.into_channel().await.unwrap();
+    let channel_url = channel.url();
+    let index_url = simple.index_url();
+
+    let pyproject = format!(
+        r#"
+[build-system]
+requires = ["setuptools"]
+build-backend = "setuptools.build_meta"
+
+[project]
+name = "recursive-optional-groups"
+
+[project.optional-dependencies]
+np = ["numpy"]
+all = ["recursive-optional-groups[np]"]
+
+[dependency-groups]
+docs = ["sphinx"]
+test = ["recursive-optional-groups[np]", "pytest", {{include-group = "docs"}}]
+
+[tool.pixi.project]
+channels = ["{channel_url}"]
+platforms = ["{platform}"]
+
+[tool.pixi.dependencies]
+python = "==3.11.0"
+
+[tool.pixi.pypi-options]
+index-url = "{index_url}"
+
+[tool.pixi.environments]
+np = {{features = ["np"]}}
+all = {{features = ["all"]}}
+test = {{features = ["test"]}}
+"#,
+        platform = platform_str,
+        channel_url = channel_url,
+        index_url = index_url,
+    );
+
+    let pixi = PixiControl::from_pyproject_manifest(&pyproject).unwrap();
+
+    let lock = pixi.update_lock_file().await.unwrap();
+
+    let numpy_req = Requirement::from_str("numpy").unwrap();
+    let sphinx_req = Requirement::from_str("sphinx").unwrap();
+    assert!(
+        lock.contains_pep508_requirement("np", platform, numpy_req.clone()),
+        "np environment should include numpy from optional dependencies"
+    );
+    assert!(
+        lock.contains_pep508_requirement("all", platform, numpy_req.clone()),
+        "all environment should include numpy inherited from recursive optional dependency"
+    );
+    assert!(
+        lock.contains_pep508_requirement("test", platform, numpy_req),
+        "test environment should include numpy inherited from recursive optional dependency"
+    );
+    assert!(
+        lock.contains_pep508_requirement("test", platform, sphinx_req),
+        "test environment should include sphinx inherited from recursive dependency group"
+    );
+}
 
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
@@ -432,6 +523,72 @@ async fn test_indexes_are_passed_when_solving_build_pypi_dependencies() {
     assert_eq!(local_pypi_index, lock_file_index,);
 }
 
+/// Ensures the unsafe-best-match index strategy is honored when resolving and building PyPI projects,
+/// even when the lower version appears first in `extra-index-urls`.
+/// This was an issue in: https://github.com/prefix-dev/pixi/issues/4588
+#[tokio::test]
+#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+async fn test_index_strategy_respected_for_build_dependencies() {
+    setup_tracing();
+
+    // The first extra index exposes the lower version while the second extra exposes the higher
+    // one. `unsafe-best-match` should still select the best version even though the lower version
+    // is encountered earlier.
+    let first_extra_index = PyPIDatabase::new()
+        .with(PyPIPackage::new("foozy", "1.0.0"))
+        .into_simple_index()
+        .unwrap();
+    let second_extra_index = PyPIDatabase::new()
+        .with(PyPIPackage::new("foozy", "2.0.0"))
+        .into_simple_index()
+        .unwrap();
+
+    let pixi = PixiControl::from_pyproject_manifest(&format!(
+        r#"
+        [project]
+        name = "index-strategy-build"
+        requires-python = ">=3.10"
+        version = "0.1.0"
+
+        [build-system]
+        requires = [
+            "uv_build>=0.8.9,<0.9.0",
+            "foozy==2.0.0",
+        ]
+        build-backend = "uv_build"
+
+        [tool.pixi.project]
+        channels = ["https://prefix.dev/conda-forge"]
+        platforms = ["{platform}"]
+
+        [tool.pixi.dependencies]
+        python = "~=3.12.0"
+
+        [tool.pixi.pypi-options]
+        extra-index-urls = [
+            "{first_extra_index}",
+            "{second_extra_index}",
+        ]
+        # Without this the test will fail
+        index-strategy = "unsafe-best-match"
+
+        [tool.pixi.pypi-dependencies]
+        index-strategy-build = {{ path = ".", editable = true }}
+        "#,
+        platform = Platform::current(),
+        first_extra_index = first_extra_index.index_url(),
+        second_extra_index = second_extra_index.index_url(),
+    ))
+    .unwrap();
+
+    let project_path = pixi.workspace_path();
+    let src_dir = project_path.join("src").join("index_strategy_build");
+    fs_err::create_dir_all(&src_dir).unwrap();
+    fs_err::write(src_dir.join("__init__.py"), "").unwrap();
+
+    pixi.install().await.unwrap();
+}
+
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_cross_platform_resolve_with_no_build() {
@@ -550,3 +707,70 @@ async fn test_pinned_help_message() {
         "The following PyPI packages have been pinned by the conda solve, and this version may be causing a conflict:\npandas==1.0.0"
     );
 }
+
+#[tokio::test]
+#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+async fn test_uv_index_correctly_parsed() {
+    setup_tracing();
+
+    // Provide a local simple index containing `foo` used in build-system requires.
+    let simple = PyPIDatabase::new()
+        .with(PyPIPackage::new("foo", "1.0.0"))
+        .into_simple_index()
+        .expect("failed to create simple index");
+
+    let pixi = PixiControl::from_pyproject_manifest(&format!(
+        r#"
+        [project]
+        name = "simple"
+        version = "0.1.0"
+        requires-python = ">=3.11"
+        dependencies = ["foo"]
+
+        [build-system]
+        requires = ["uv_build>=0.8.9,<0.9.0"]
+        build-backend = "uv_build"
+
+
+        [tool.uv.sources]
+        foo = [
+        {{ index = "our_index" }},
+        ]
+
+        [[tool.uv.index]]
+        name = "our_index"
+        url = "{index_url}"
+        explicit = true
+
+        [tool.uv.build-backend]
+        module-name = "simple"
+        module-root = ""
+
+        [tool.pixi.workspace]
+        channels = ["conda-forge"]
+        platforms = ["{platform}"]
+
+        [tool.pixi.pypi-dependencies]
+        simple = {{ path = "." }}
+        "#,
+        platform = Platform::current(),
+        index_url = simple.index_url(),
+    ))
+    .unwrap();
+
+    let project_path = pixi.workspace_path();
+    let src_dir = project_path.join("src").join("simple");
+    fs_err::create_dir_all(&src_dir).unwrap();
+    fs_err::write(src_dir.join("__init__.py"), "").unwrap();
+
+    let lock_file = pixi.update_lock_file().await.unwrap();
+    assert!(
+        lock_file
+            .get_pypi_package_url("default", Platform::current(), "foo")
+            .unwrap()
+            .as_path()
+            .unwrap()
+            .as_str()
+            .contains(&simple.index_path().display().to_string())
+    );
+}
