@@ -12,9 +12,12 @@ use jsonrpsee::{
     types::ErrorCode,
 };
 use miette::Diagnostic;
+use ordermap::OrderMap;
 use pixi_build_types::{
-    BackendCapabilities, FrontendCapabilities, ProjectModelV1, VersionedProjectModel, procedures,
+    BackendCapabilities, FrontendCapabilities, ProjectModelV1, TargetSelectorV1,
+    VersionedProjectModel,
     procedures::{
+        self,
         conda_build_v0::{CondaBuildParams, CondaBuildResult},
         conda_build_v1::{CondaBuildV1Params, CondaBuildV1Result},
         conda_metadata::{CondaMetadataParams, CondaMetadataResult},
@@ -23,6 +26,7 @@ use pixi_build_types::{
         negotiate_capabilities::{NegotiateCapabilitiesParams, NegotiateCapabilitiesResult},
     },
 };
+use rattler_conda_types::VersionWithSource;
 use thiserror::Error;
 use tokio::{
     io::{AsyncBufReadExt, BufReader, Lines},
@@ -123,6 +127,8 @@ impl CommunicationError {
 pub struct JsonRpcBackend {
     /// The identifier of the backend.
     backend_identifier: String,
+    /// The version of the backend.
+    backend_version: Option<VersionWithSource>,
     /// The capabilities of the backend.
     backend_capabilities: BackendCapabilities,
     /// The JSON-RPC client to communicate with the backend.
@@ -141,11 +147,16 @@ impl JsonRpcBackend {
     pub async fn setup(
         source_dir: PathBuf,
         manifest_path: PathBuf,
+        workspace_root: PathBuf,
         package_manifest: Option<ProjectModelV1>,
         configuration: Option<serde_json::Value>,
+        target_configuration: Option<OrderMap<TargetSelectorV1, serde_json::Value>>,
         cache_dir: Option<PathBuf>,
         tool: Tool,
     ) -> Result<Self, InitializeError> {
+        debug_assert!(source_dir.is_absolute());
+        debug_assert!(manifest_path.is_absolute());
+        debug_assert!(workspace_root.is_absolute());
         // Spawn the tool and capture stdin/stdout.
         let command = tool.command();
         let program_name = command.get_program().to_string_lossy().into_owned();
@@ -183,10 +194,13 @@ impl JsonRpcBackend {
         let (tx, rx) = stdio_transport(stdin, stdout);
         Self::setup_with_transport(
             backend_identifier,
+            tool.version().cloned(),
             source_dir,
             manifest_path,
+            workspace_root,
             package_manifest,
             configuration,
+            target_configuration,
             cache_dir,
             tx,
             rx,
@@ -199,10 +213,13 @@ impl JsonRpcBackend {
     #[allow(clippy::too_many_arguments)]
     pub(crate) async fn setup_with_transport(
         backend_identifier: String,
+        backend_version: Option<VersionWithSource>,
         source_dir: PathBuf,
         manifest_path: PathBuf,
+        workspace_root: PathBuf,
         project_model: Option<ProjectModelV1>,
         configuration: Option<serde_json::Value>,
+        target_configuration: Option<OrderMap<TargetSelectorV1, serde_json::Value>>,
         cache_dir: Option<PathBuf>,
         sender: impl TransportSenderT + Send,
         receiver: impl TransportReceiverT + Send,
@@ -239,8 +256,10 @@ impl JsonRpcBackend {
                 RpcParams::from(InitializeParams {
                     project_model: project_model.map(VersionedProjectModel::V1),
                     configuration,
+                    target_configuration,
                     manifest_path: manifest_path.clone(),
                     source_dir: Some(source_dir),
+                    workspace_root: Some(workspace_root),
                     cache_directory: cache_dir,
                 }),
             )
@@ -258,6 +277,7 @@ impl JsonRpcBackend {
         Ok(Self {
             client,
             backend_identifier,
+            backend_version,
             backend_capabilities: negotiate_result.capabilities,
             manifest_path,
             stderr: stderr.map(Mutex::new).map(Arc::new),
@@ -473,6 +493,11 @@ impl JsonRpcBackend {
         &self.backend_identifier
     }
 
+    /// Returns the version of the backend, if available.
+    pub fn version(&self) -> Option<&VersionWithSource> {
+        self.backend_version.as_ref()
+    }
+
     /// Returns the advertised capabilities of the backend.
     pub fn capabilities(&self) -> &BackendCapabilities {
         &self.backend_capabilities
