@@ -21,14 +21,13 @@
 use std::{convert::Infallible, fmt::Display, hash::Hash, path::PathBuf, str::FromStr};
 
 use ordermap::OrderMap;
+use pixi_stable_hash::{IsDefault, StableHashBuilder};
 use rattler_conda_types::{BuildNumberSpec, StringMatcher, Version, VersionSpec};
 use rattler_digest::{Md5, Md5Hash, Sha256, Sha256Hash, serde::SerializableHash};
 use serde::{Deserialize, Serialize};
 use serde_with::{DeserializeFromStr, DisplayFromStr, SerializeDisplay, serde_as};
 use url::Url;
 
-use crate::stable_hash::{IsDefault, StableHashBuilder};
-
 /// Enum containing all versions of the project model.
 #[derive(Debug, Clone, Serialize, Deserialize)]
 #[serde(tag = "version", content = "data")]
@@ -74,7 +73,7 @@ pub type SourcePackageName = String;
 #[serde(rename_all = "camelCase")]
 pub struct ProjectModelV1 {
     /// The name of the project
-    pub name: String,
+    pub name: Option<String>,
 
     /// The version of the project
     pub version: Option<Version>,
@@ -108,6 +107,14 @@ pub struct ProjectModelV1 {
     pub targets: Option<TargetsV1>,
 }
 
+impl IsDefault for ProjectModelV1 {
+    type Item = Self;
+
+    fn is_non_default(&self) -> Option<&Self::Item> {
+        Some(self)
+    }
+}
+
 impl From<ProjectModelV1> for VersionedProjectModel {
     fn from(value: ProjectModelV1) -> Self {
         VersionedProjectModel::V1(value)
@@ -176,17 +183,10 @@ impl TargetsV1 {
 }
 
 impl IsDefault for TargetsV1 {
-    fn is_default(&self) -> bool {
-        self.is_empty()
-    }
-}
+    type Item = Self;
 
-impl<T: IsDefault> IsDefault for Option<T> {
-    fn is_default(&self) -> bool {
-        match self {
-            None => true,
-            Some(value) => value.is_default(),
-        }
+    fn is_non_default(&self) -> Option<&Self::Item> {
+        if !self.is_empty() { Some(self) } else { None }
     }
 }
 
@@ -219,8 +219,10 @@ impl TargetV1 {
 }
 
 impl IsDefault for TargetV1 {
-    fn is_default(&self) -> bool {
-        self.is_empty()
+    type Item = Self;
+
+    fn is_non_default(&self) -> Option<&Self::Item> {
+        if !self.is_empty() { Some(self) } else { None }
     }
 }
 
@@ -601,8 +603,10 @@ impl Hash for GitReferenceV1 {
 }
 
 impl IsDefault for GitReferenceV1 {
-    fn is_default(&self) -> bool {
-        false // Never skip GitReferenceV1 fields
+    type Item = Self;
+
+    fn is_non_default(&self) -> Option<&Self::Item> {
+        Some(self) // Never skip GitReferenceV1 fields
     }
 }
 
@@ -633,7 +637,7 @@ mod tests {
     use super::*;
 
     fn calculate_hash<T: Hash>(obj: &T) -> u64 {
-        let mut hasher = DefaultHasher::new();
+        let mut hasher = DefaultHasher::default();
         obj.hash(&mut hasher);
         hasher.finish()
     }
@@ -642,7 +646,7 @@ mod tests {
     fn test_hash_stability_with_default_values() {
         // Create a minimal ProjectModelV1 instance
         let mut project_model = ProjectModelV1 {
-            name: "test-project".to_string(),
+            name: Some("test-project".to_string()),
             version: None,
             description: None,
             authors: None,
@@ -698,7 +702,7 @@ mod tests {
     fn test_hash_changes_with_meaningful_values() {
         // Create a minimal ProjectModelV1 instance
         let mut project_model = ProjectModelV1 {
-            name: "test-project".to_string(),
+            name: Some("test-project".to_string()),
             version: None,
             description: None,
             authors: None,
@@ -993,14 +997,14 @@ mod tests {
     fn test_hash_collision_bug_project_model() {
         // Test the same issue in ProjectModelV1
         let project1 = ProjectModelV1 {
-            name: "test".to_string(),
+            name: Some("test".to_string()),
             description: Some("test description".to_string()),
             license: None,
             ..Default::default()
         };
 
         let project2 = ProjectModelV1 {
-            name: "test".to_string(),
+            name: Some("test".to_string()),
             description: None,
             license: Some("test description".to_string()),
             ..Default::default()
