@@ -5,10 +5,14 @@ use std::{
     string::String,
 };
 
+#[cfg(unix)]
+use std::io::IsTerminal;
+
 use clap::Parser;
 use deno_task_shell::KillSignal;
 use dialoguer::theme::ColorfulTheme;
 use fancy_display::FancyDisplay;
+use indicatif::ProgressDrawTarget;
 use itertools::Itertools;
 use miette::{Diagnostic, IntoDiagnostic};
 use pixi_config::{ConfigCli, ConfigCliActivation};
@@ -19,6 +23,7 @@ use pixi_core::{
     workspace::{Environment, errors::UnsupportedPlatformError},
 };
 use pixi_manifest::{FeaturesExt, TaskName};
+use pixi_progress::global_multi_progress;
 use pixi_task::{
     AmbiguousTask, CanSkip, ExecutableTask, FailedToParseShellScript, InvalidWorkingDirectory,
     SearchEnvironments, TaskAndEnvironment, TaskGraph, get_task_env,
@@ -88,6 +93,11 @@ pub struct Args {
 /// When running the sigints are ignored and child can react to them. As it
 /// pleases.
 pub async fn execute(args: Args) -> miette::Result<()> {
+    // Following statements don't spawn any progress bar, so set
+    // progress draw target to hidden. Otherwise output may be
+    // incorrect.
+    global_multi_progress().set_draw_target(ProgressDrawTarget::hidden());
+
     let cli_config = args
         .activation_config
         .merge_config(args.config.clone().into());
@@ -114,6 +124,10 @@ pub async fn execute(args: Args) -> miette::Result<()> {
         return Ok(());
     }
 
+    // We expect progress bar to be used afterwards, so set draw
+    // target to the original one.
+    global_multi_progress().set_draw_target(ProgressDrawTarget::stderr_with_hz(20));
+
     // Sanity check of prefix location
     sanity_check_workspace(&workspace).await?;
 
@@ -302,9 +316,16 @@ pub async fn execute(args: Args) -> miette::Result<()> {
             Err(err) => return Err(err.into()),
         }
 
-        // Update the task cache with the new hash
+        // Compute post-run hash, warn on missing globs, and update the cache
+        let post_hash = executable_task
+            .compute_post_run_hash(lock_file.as_lock_file(), task_cache)
+            .await
+            .into_diagnostic()?;
+        if let Some(ref hash) = post_hash {
+            executable_task.warn_on_missing_globs(hash);
+        }
         executable_task
-            .save_cache(lock_file.as_lock_file(), task_cache)
+            .save_cache(post_hash)
             .await
             .into_diagnostic()?;
     }
@@ -456,7 +477,7 @@ fn reset_cursor() {
 ///
 /// Signal listeners and ctrl+c listening will be setup.
 pub async fn run_future_forwarding_signals<TOutput>(
-    kill_signal: KillSignal,
+    #[cfg_attr(windows, allow(unused_variables))] kill_signal: KillSignal,
     future: impl std::future::Future<Output = TOutput>,
 ) -> TOutput {
     fn spawn_future_with_cancellation(
@@ -477,7 +498,9 @@ pub async fn run_future_forwarding_signals<TOutput>(
 
     local_set
         .run_until(async move {
-            spawn_future_with_cancellation(listen_ctrl_c(kill_signal.clone()), token.clone());
+            #[cfg(windows)]
+            spawn_future_with_cancellation(listen_ctrl_c_windows(), token.clone());
+
             #[cfg(unix)]
             spawn_future_with_cancellation(listen_and_forward_all_signals(kill_signal), token);
 
@@ -486,18 +509,27 @@ pub async fn run_future_forwarding_signals<TOutput>(
         .await
 }
 
-async fn listen_ctrl_c(kill_signal: KillSignal) {
-    while let Ok(()) = tokio::signal::ctrl_c().await {
-        // On windows, ctrl+c is sent to the process group, so the signal would
-        // have already been sent to the child process. We still want to listen
-        // for ctrl+c here to keep the process alive when receiving it, but no
-        // need to forward the signal because it's already been sent.
-        if !cfg!(windows) {
-            kill_signal.send(deno_task_shell::SignalKind::SIGINT)
-        }
-    }
+#[cfg(windows)]
+async fn listen_ctrl_c_windows() {
+    // On windows, ctrl+c is sent to the process group, so the signal would
+    // have already been sent to the child process. We still want to listen
+    // for ctrl+c here to keep the process alive when receiving it, but no
+    // need to forward the signal because it's already been sent.
+    while let Ok(()) = tokio::signal::ctrl_c().await {}
 }
 
+/// Listens to all incoming signals and forwards all of them, except
+/// some cases.
+///
+/// Note that we don't handle `SIGINT` correctly, if the subprocess changes
+/// its PGID, then the system won't forward CTRL+C automatically.
+/// However, we should do that to ensure consistent behaviour.
+///
+/// To resolve this we should patch `deno_task_shell` to return PID
+/// from which we could get PGID and do things right.
+///
+/// Resulting approach should mimic
+/// https://github.com/astral-sh/uv/blob/9d17dfa3537312b928f94479f632891f918c4760/crates/uv/src/child.rs#L156C21-L168C77.
 #[cfg(unix)]
 async fn listen_and_forward_all_signals(kill_signal: KillSignal) {
     use futures::FutureExt;
@@ -506,8 +538,12 @@ async fn listen_and_forward_all_signals(kill_signal: KillSignal) {
 
     // listen and forward every signal we support
     let mut futures = Vec::with_capacity(SIGNALS.len());
+    let is_interactive = std::io::stdin().is_terminal();
     for signo in SIGNALS.iter().copied() {
-        if signo == libc::SIGKILL || signo == libc::SIGSTOP {
+        if signo == libc::SIGKILL
+            || signo == libc::SIGSTOP
+            || (signo == libc::SIGINT && is_interactive)
+        {
             continue; // skip, can't listen to these
         }
 
