@@ -54,9 +54,14 @@ impl CommandDispatcherProcessor {
         // Add the task to the list of pending futures.
         let dispatcher = self.create_task_command_dispatcher(dispatcher_context);
         self.pending_futures.push(
-            task.spec
-                .solve(dispatcher, gateway_reporter)
-                .map(move |result| TaskResult::SolvePixiEnvironment(pending_env_id, result))
+            task.cancellation_token
+                .run_until_cancelled_owned(task.spec.solve(dispatcher, gateway_reporter))
+                .map(move |result| {
+                    TaskResult::SolvePixiEnvironment(
+                        pending_env_id,
+                        result.unwrap_or(Err(CommandDispatcherError::Cancelled)),
+                    )
+                })
                 .boxed_local(),
         );
     }
