@@ -1,10 +1,11 @@
 use std::{
     collections::BTreeMap,
     path::{Path, PathBuf},
+    sync::Arc,
 };
 
 use miette::Diagnostic;
-use pixi_build_discovery::{DiscoveredBackend, EnabledProtocols};
+use pixi_build_discovery::EnabledProtocols;
 use pixi_build_frontend::Backend;
 use pixi_build_types::procedures::conda_outputs::CondaOutputsParams;
 use pixi_record::{PinnedSourceSpec, PixiRecord};
@@ -14,6 +15,7 @@ use rattler_conda_types::{
     Platform, RepoDataRecord, prefix::Prefix,
 };
 use rattler_digest::Sha256Hash;
+use rattler_repodata_gateway::{RunExportExtractorError, RunExportsReporter};
 use serde::Serialize;
 use thiserror::Error;
 use tracing::instrument;
@@ -29,8 +31,8 @@ use crate::{
     SourceBuildCacheStatusSpec, SourceCheckoutError,
     build::{
         BuildCacheError, BuildHostEnvironment, BuildHostPackage, CachedBuild,
-        CachedBuildSourceInfo, Dependencies, DependenciesError, MoveError, SourceRecordOrCheckout,
-        WorkDirKey, move_file,
+        CachedBuildSourceInfo, Dependencies, DependenciesError, MoveError, PackageBuildInputHash,
+        PixiRunExports, SourceRecordOrCheckout, WorkDirKey, move_file,
     },
     package_identifier::PackageIdentifier,
 };
@@ -107,10 +109,18 @@ pub struct BuiltPackage {
 }
 
 impl SourceBuildSpec {
-    #[instrument(skip_all, fields(package = %self.package, source = %self.source))]
+    #[instrument(
+        skip_all,
+        name = "source-build",
+        fields(
+            source= %self.source,
+            package = %self.package,
+        )
+    )]
     pub(crate) async fn build(
         mut self,
         command_dispatcher: CommandDispatcher,
+        reporter: Option<Arc<dyn RunExportsReporter>>,
     ) -> Result<SourceBuildResult, CommandDispatcherError<SourceBuildError>> {
         // If the output directory is not set, we want to use the build cache. Read the
         // build cache in that case.
@@ -125,6 +135,8 @@ impl SourceBuildSpec {
                         build_environment: self.build_environment.clone(),
                         source: self.source.clone(),
                         channels: self.channels.clone(),
+                        channel_config: self.channel_config.clone(),
+                        enabled_protocols: self.enabled_protocols.clone(),
                     })
                     .await
                     .map_err_with(SourceBuildError::from)?;
@@ -146,20 +158,28 @@ impl SourceBuildSpec {
             .await
             .map_err_with(SourceBuildError::SourceCheckout)?;
 
-        // Discover information about the build backend from the source code.
-        let discovered_backend = DiscoveredBackend::discover(
-            &source_checkout.path,
-            &self.channel_config,
-            &self.enabled_protocols,
-        )
-        .map_err(SourceBuildError::Discovery)
-        .map_err(CommandDispatcherError::Failed)?;
+        // Discover information about the build backend from the source code (cached by
+        // path).
+        let discovered_backend = command_dispatcher
+            .discover_backend(
+                &source_checkout.path,
+                self.channel_config.clone(),
+                self.enabled_protocols.clone(),
+            )
+            .await
+            .map_err_with(SourceBuildError::Discovery)?;
+
+        // Compute the package input hash for caching purposes.
+        let package_build_input_hash = PackageBuildInputHash::from(discovered_backend.as_ref());
 
         // Instantiate the backend with the discovered information.
         let backend = command_dispatcher
             .instantiate_backend(InstantiateBackendSpec {
-                backend_spec: discovered_backend.backend_spec,
-                init_params: discovered_backend.init_params,
+                backend_spec: discovered_backend
+                    .backend_spec
+                    .clone()
+                    .resolve(SourceAnchor::from(SourceSpec::from(self.source.clone()))),
+                init_params: discovered_backend.init_params.clone(),
                 channel_config: self.channel_config.clone(),
                 enabled_protocols: self.enabled_protocols.clone(),
             })
@@ -193,11 +213,22 @@ impl SourceBuildSpec {
 
         // Build the package based on the support backend capabilities.
         let mut built_source = if backend.capabilities().provides_conda_build_v1() {
-            self.build_v1(command_dispatcher, backend, work_directory)
-                .await?
+            self.build_v1(
+                command_dispatcher,
+                backend,
+                work_directory,
+                package_build_input_hash,
+                reporter,
+            )
+            .await?
         } else {
-            self.build_v0(command_dispatcher, backend, work_directory)
-                .await?
+            self.build_v0(
+                command_dispatcher,
+                backend,
+                work_directory,
+                package_build_input_hash,
+            )
+            .await?
         };
 
         // Create the output directory if it does not exist.
@@ -300,13 +331,12 @@ impl SourceBuildSpec {
         command_dispatcher: CommandDispatcher,
         backend: Backend,
         work_directory: PathBuf,
+        package_build_input_hash: PackageBuildInputHash,
     ) -> Result<BuiltPackage, CommandDispatcherError<SourceBuildError>> {
         let result = command_dispatcher
             .backend_source_build(BackendSourceBuildSpec {
                 method: BackendSourceBuildMethod::BuildV0(BackendSourceBuildV0Method {
                     editable: self.editable(),
-                    channel_config: self.channel_config,
-                    channels: self.channels,
                     build_environment: self.build_environment,
                     variants: self.variants,
                     output_directory: self.output_directory,
@@ -315,6 +345,8 @@ impl SourceBuildSpec {
                 package: self.package,
                 source: self.source,
                 work_directory,
+                channels: self.channels,
+                channel_config: self.channel_config,
             })
             .await
             .map_err_with(SourceBuildError::from)?;
@@ -325,6 +357,7 @@ impl SourceBuildSpec {
                 globs: result.input_globs,
                 build: Default::default(),
                 host: Default::default(),
+                package_build_input_hash: Some(package_build_input_hash),
             },
         })
     }
@@ -334,6 +367,8 @@ impl SourceBuildSpec {
         command_dispatcher: CommandDispatcher,
         backend: Backend,
         work_directory: PathBuf,
+        package_build_input_hash: PackageBuildInputHash,
+        reporter: Option<Arc<dyn RunExportsReporter>>,
     ) -> Result<BuiltPackage, CommandDispatcherError<SourceBuildError>> {
         let source_anchor = SourceAnchor::from(SourceSpec::from(self.source.clone()));
         let host_platform = self.build_environment.host_platform;
@@ -347,6 +382,7 @@ impl SourceBuildSpec {
                 build_platform,
                 variant_configuration: self.variants.clone(),
                 work_directory: work_directory.clone(),
+                channels: self.channels.clone(),
             })
             .await
             .map_err(BackendSourceBuildError::BuildError)
@@ -384,7 +420,7 @@ impl SourceBuildSpec {
             .map_err(SourceBuildError::from)
             .map_err(CommandDispatcherError::Failed)?
             .unwrap_or_default();
-        let build_records = self
+        let mut build_records = self
             .solve_dependencies(
                 format!("{} (build)", self.package.name.as_source()),
                 &command_dispatcher,
@@ -394,8 +430,18 @@ impl SourceBuildSpec {
             .await
             .map_err_with(Box::new)
             .map_err_with(SourceBuildError::SolveBuildEnvironment)?;
-        let build_run_exports =
-            build_dependencies.extract_run_exports(&build_records, &output.ignore_run_exports);
+
+        let gateway = command_dispatcher.gateway();
+        let build_run_exports = build_dependencies
+            .extract_run_exports(
+                &mut build_records,
+                &output.ignore_run_exports,
+                gateway,
+                reporter.clone(),
+            )
+            .await
+            .map_err(SourceBuildError::from)
+            .map_err(CommandDispatcherError::Failed)?;
 
         // Solve the host environment for the output.
         let host_dependencies = output
@@ -408,7 +454,7 @@ impl SourceBuildSpec {
             .unwrap_or_default()
             // Extend with the run exports from the build environment.
             .extend_with_run_exports_from_build(&build_run_exports);
-        let host_records = self
+        let mut host_records = self
             .solve_dependencies(
                 format!("{} (host)", self.package.name.as_source()),
                 &command_dispatcher,
@@ -418,6 +464,16 @@ impl SourceBuildSpec {
             .await
             .map_err_with(Box::new)
             .map_err_with(SourceBuildError::SolveBuildEnvironment)?;
+        let host_run_exports = host_dependencies
+            .extract_run_exports(
+                &mut host_records,
+                &output.ignore_run_exports,
+                command_dispatcher.gateway(),
+                reporter,
+            )
+            .await
+            .map_err(SourceBuildError::from)
+            .map_err(CommandDispatcherError::Failed)?;
 
         // Install the build environment
         let build_prefix = if build_records.is_empty() {
@@ -432,6 +488,7 @@ impl SourceBuildSpec {
                             .map_err(SourceBuildError::CreateBuildEnvironmentDirectory)
                             .map_err(CommandDispatcherError::Failed)?,
                         installed: None,
+                        ignore_packages: None,
                         build_environment: self.build_environment.to_build_from_build(),
                         force_reinstall: Default::default(),
                         channels: self.channels.clone(),
@@ -458,6 +515,7 @@ impl SourceBuildSpec {
                             .map_err(SourceBuildError::CreateBuildEnvironmentDirectory)
                             .map_err(CommandDispatcherError::Failed)?,
                         installed: None,
+                        ignore_packages: None,
                         build_environment: self.build_environment.to_build_from_build(),
                         force_reinstall: Default::default(),
                         channels: self.channels.clone(),
@@ -476,19 +534,48 @@ impl SourceBuildSpec {
             CommandDispatcherError::Failed(SourceBuildError::CreateWorkDirectory(err))
         })?;
 
+        // Gather the dependencies for the output.
+        let dependencies = Dependencies::new(&output.run_dependencies, None)
+            .map_err(SourceBuildError::from)
+            .map_err(CommandDispatcherError::Failed)?
+            .extend_with_run_exports_from_build_and_host(
+                host_run_exports,
+                build_run_exports,
+                output.metadata.subdir,
+            );
+
+        // Convert the run exports
+        let run_exports = PixiRunExports::try_from_protocol(&output.run_exports)
+            .map_err(SourceBuildError::from)
+            .map_err(CommandDispatcherError::Failed)?;
+
+        // Extract the repodata records from the build and host environments.
+        let build_records = Self::extract_prefix_repodata(build_records, build_prefix);
+        let host_records = Self::extract_prefix_repodata(host_records, host_prefix);
+
         let built_source = command_dispatcher
             .backend_source_build(BackendSourceBuildSpec {
                 method: BackendSourceBuildMethod::BuildV1(BackendSourceBuildV1Method {
                     editable: self.editable(),
+                    dependencies,
+                    run_exports,
                     build_prefix: BackendSourceBuildPrefix {
                         platform: self.build_environment.build_platform,
                         prefix: directories.build_prefix,
-                        records: build_records.clone(),
+                        dependencies: build_dependencies,
+                        records: build_records
+                            .iter()
+                            .map(|p| p.repodata_record.clone())
+                            .collect(),
                     },
                     host_prefix: BackendSourceBuildPrefix {
                         platform: self.build_environment.host_platform,
                         prefix: directories.host_prefix,
-                        records: host_records.clone(),
+                        dependencies: host_dependencies,
+                        records: host_records
+                            .iter()
+                            .map(|p| p.repodata_record.clone())
+                            .collect(),
                     },
                     variant: output.metadata.variant,
                     output_directory: self.output_directory,
@@ -497,54 +584,59 @@ impl SourceBuildSpec {
                 package: self.package,
                 source: self.source,
                 work_directory,
+                channels: self.channels,
+                channel_config: self.channel_config,
             })
             .await
             .map_err_with(SourceBuildError::from)?;
 
-        // Little helper function the build a `BuildHostEnvironment` from expected and
-        // installed records.
-        let build_host_environment =
-            |records: Vec<PixiRecord>, prefix: Option<InstallPixiEnvironmentResult>| {
-                let Some(prefix) = prefix else {
-                    return BuildHostEnvironment { packages: vec![] };
-                };
-
-                BuildHostEnvironment {
-                    packages: records
-                        .into_iter()
-                        .map(|record| match record {
-                            PixiRecord::Binary(repodata_record) => BuildHostPackage {
-                                repodata_record,
-                                source: None,
-                            },
-                            PixiRecord::Source(source) => {
-                                let repodata_record = prefix
-                                    .resolved_source_records
-                                    .get(&source.package_record.name)
-                                    .cloned()
-                                    .expect(
-                                        "the source record should be present in the result sources",
-                                    );
-                                BuildHostPackage {
-                                    repodata_record,
-                                    source: Some(source.source),
-                                }
-                            }
-                        })
-                        .collect(),
-                }
-            };
-
         Ok(BuiltPackage {
             output_file: built_source.output_file,
             metadata: CachedBuildSourceInfo {
                 globs: built_source.input_globs,
-                build: build_host_environment(build_records, build_prefix),
-                host: build_host_environment(host_records, host_prefix),
+                build: BuildHostEnvironment {
+                    packages: build_records,
+                },
+                host: BuildHostEnvironment {
+                    packages: host_records,
+                },
+                package_build_input_hash: Some(package_build_input_hash),
             },
         })
     }
 
+    /// Little helper function the build a `BuildHostPackage` from expected and
+    /// installed records.
+    fn extract_prefix_repodata(
+        records: Vec<PixiRecord>,
+        prefix: Option<InstallPixiEnvironmentResult>,
+    ) -> Vec<BuildHostPackage> {
+        let Some(prefix) = prefix else {
+            return vec![];
+        };
+
+        records
+            .into_iter()
+            .map(|record| match record {
+                PixiRecord::Binary(repodata_record) => BuildHostPackage {
+                    repodata_record,
+                    source: None,
+                },
+                PixiRecord::Source(source) => {
+                    let repodata_record = prefix
+                        .resolved_source_records
+                        .get(&source.package_record.name)
+                        .cloned()
+                        .expect("the source record should be present in the result sources");
+                    BuildHostPackage {
+                        repodata_record,
+                        source: Some(source.source),
+                    }
+                }
+            })
+            .collect()
+    }
+
     async fn solve_dependencies(
         &self,
         name: String,
@@ -558,8 +650,16 @@ impl SourceBuildSpec {
         command_dispatcher
             .solve_pixi_environment(PixiEnvironmentSpec {
                 name: Some(name),
-                dependencies: dependencies.dependencies,
-                constraints: dependencies.constraints,
+                dependencies: dependencies
+                    .dependencies
+                    .into_specs()
+                    .map(|(name, spec)| (name, spec.value))
+                    .collect(),
+                constraints: dependencies
+                    .constraints
+                    .into_specs()
+                    .map(|(name, spec)| (name, spec.value))
+                    .collect(),
                 installed: vec![], // TODO: To lock build environments, fill this.
                 build_environment,
                 channels: self.channels.clone(),
@@ -636,6 +736,9 @@ pub enum SourceBuildError {
     #[error(transparent)]
     BuildCache(#[from] BuildCacheError),
 
+    #[error("failed to amend run exports: {0}")]
+    RunExportsExtraction(#[from] RunExportExtractorError),
+
     #[error(transparent)]
     CreateWorkDirectory(std::io::Error),
 
@@ -728,6 +831,7 @@ impl From<SourceBuildCacheStatusError> for SourceBuildError {
     fn from(value: SourceBuildCacheStatusError) -> Self {
         match value {
             SourceBuildCacheStatusError::BuildCache(err) => SourceBuildError::BuildCache(err),
+            SourceBuildCacheStatusError::Discovery(err) => SourceBuildError::Discovery(err),
             SourceBuildCacheStatusError::SourceCheckout(err) => {
                 SourceBuildError::SourceCheckout(err)
             }
