@@ -6,12 +6,13 @@ import json
 from copy import deepcopy
 from pathlib import Path
 import tomllib
-from typing import Annotated, Any, Optional, Literal
+from typing import Annotated, Any, Literal, ClassVar, override
 from enum import Enum
 
 from pydantic import (
     AnyHttpUrl,
     BaseModel,
+    ConfigDict,
     Field,
     PositiveFloat,
     StringConstraints,
@@ -69,9 +70,7 @@ class Platform(str, Enum):
 
 
 class StrictBaseModel(BaseModel):
-    class Config:
-        extra = "forbid"
-        alias_generator = hyphenize
+    model_config: ClassVar[ConfigDict] = ConfigDict(extra="forbid", alias_generator=hyphenize)
 
 
 class WorkspaceInheritance(StrictBaseModel):
@@ -135,9 +134,9 @@ class Workspace(StrictBaseModel):
     channel_priority: ChannelPriority | None = Field(
         None,
         examples=["strict", "disabled"],
-        description="The type of channel priority that is used in the solve."
-        "- 'strict': only take the package from the channel it exist in first."
-        "- 'disabled': group all dependencies together as if there is no channel difference.",
+        description="""The type of channel priority that is used in the solve.
+- 'strict': only take the package from the channel it exist in first.
+- 'disabled': group all dependencies together as if there is no channel difference.""",
     )
     exclude_newer: ExcludeNewer | None = Field(
         None,
@@ -242,7 +241,7 @@ class _PyPIRequirement(StrictBaseModel):
 
 
 class _PyPiGitRequirement(_PyPIRequirement):
-    git: NonEmptyStr = Field(
+    git: NonEmptyStr | None = Field(
         None,
         description="The `git` URL to the repo e.g https://github.com/prefix-dev/pixi",
     )
@@ -252,23 +251,23 @@ class _PyPiGitRequirement(_PyPIRequirement):
 
 
 class PyPIGitRevRequirement(_PyPiGitRequirement):
-    rev: Optional[NonEmptyStr] = Field(None, description="A `git` SHA revision to use")
+    rev: NonEmptyStr | None = Field(None, description="A `git` SHA revision to use")
 
 
 class PyPIGitBranchRequirement(_PyPiGitRequirement):
-    branch: Optional[NonEmptyStr] = Field(None, description="A `git` branch to use")
+    branch: NonEmptyStr | None = Field(None, description="A `git` branch to use")
 
 
 class PyPIGitTagRequirement(_PyPiGitRequirement):
-    tag: Optional[NonEmptyStr] = Field(None, description="A `git` tag to use")
+    tag: NonEmptyStr | None = Field(None, description="A `git` tag to use")
 
 
 class PyPIPathRequirement(_PyPIRequirement):
-    path: NonEmptyStr = Field(
+    path: NonEmptyStr | None = Field(
         None,
         description="A path to a local source or wheel",
     )
-    editable: Optional[bool] = Field(
+    editable: bool | None = Field(
         None, description="If `true` the package will be installed as editable"
     )
     subdirectory: NonEmptyStr | None = Field(
@@ -277,14 +276,14 @@ class PyPIPathRequirement(_PyPIRequirement):
 
 
 class PyPIUrlRequirement(_PyPIRequirement):
-    url: NonEmptyStr = Field(
+    url: NonEmptyStr | None = Field(
         None,
         description="A URL to a remote source or wheel",
     )
 
 
 class PyPIVersion(_PyPIRequirement):
-    version: NonEmptyStr = Field(
+    version: NonEmptyStr | None = Field(
         None,
         description="The version of the package in [PEP 440](https://www.python.org/dev/peps/pep-0440/) format",
     )
@@ -453,7 +452,7 @@ class Environment(StrictBaseModel):
         None,
         description="The group name for environments that should be solved together",
     )
-    no_default_feature: Optional[bool] = Field(
+    no_default_feature: bool = Field(
         False,
         description="Whether to add the default feature to this environment",
     )
@@ -521,9 +520,9 @@ class Feature(StrictBaseModel):
     channel_priority: ChannelPriority | None = Field(
         None,
         examples=["strict", "disabled"],
-        description="The type of channel priority that is used in the solve."
-        "- 'strict': only take the package from the channel it exist in first."
-        "- 'disabled': group all dependencies together as if there is no channel difference.",
+        description="""The type of channel priority that is used in the solve.
+- 'strict': only take the package from the channel it exist in first.
+- 'disabled': group all dependencies together as if there is no channel difference.""",
     )
     platforms: list[Platform] | None = Field(
         None,
@@ -606,7 +605,7 @@ class PyPIOptions(StrictBaseModel):
         description="Additional PyPI registries that should be used as extra indexes",
         examples=[["https://pypi.org/simple"]],
     )
-    find_links: list[FindLinksPath | FindLinksURL] = Field(
+    find_links: list[FindLinksPath | FindLinksURL] | None = Field(
         None,
         description="Paths to directory containing",
         examples=[["https://pypi.org/simple"]],
@@ -709,7 +708,7 @@ class Package(StrictBaseModel):
 class BuildTarget(StrictBaseModel):
     """Target-specific build configuration for different platforms"""
 
-    config: dict[str, Any] = Field(
+    config: dict[str, Any] | None = Field(
         None, description="Target-specific configuration for the build backend"
     )
 
@@ -733,19 +732,21 @@ class SourceLocation(StrictBaseModel):
 
 class Build(StrictBaseModel):
     backend: BuildBackend = Field(..., description="The build backend to instantiate")
-    channels: list[Channel] = Field(
+    channels: list[Channel] | None = Field(
         None, description="The `conda` channels that are used to fetch the build backend from"
     )
     additional_dependencies: Dependencies = Field(
         None, description="Additional dependencies to install alongside the build backend"
     )
-    config: dict[str, Any] = Field(None, description="The configuration of the build backend")
+    config: dict[str, Any] | None = Field(
+        None, description="The configuration of the build backend"
+    )
     target: dict[TargetName, BuildTarget] | None = Field(
         None,
         description="Target-specific build configuration for different platforms",
         examples=[{"linux-64": {"config": {"key": "value"}}}],
     )
-    source: SourceLocation = Field(
+    source: SourceLocation | None = Field(
         None,
         description="The source from which to build the package",
         examples=[{"path": "project"}],
@@ -753,7 +754,7 @@ class Build(StrictBaseModel):
 
 
 class BuildBackend(MatchspecTable):
-    name: NonEmptyStr = Field(None, description="The name of the build backend package")
+    name: NonEmptyStr | None = Field(None, description="The name of the build backend package")
     channels: list[Channel] | None = Field(
         None, description="The `conda` channels that are used to fetch the build backend from"
     )
@@ -776,8 +777,8 @@ class PackageTarget(StrictBaseModel):
 class BaseManifest(StrictBaseModel):
     """The configuration for a [`pixi`](https://pixi.sh) project."""
 
-    class Config:
-        json_schema_extra = {
+    model_config: ClassVar[ConfigDict] = ConfigDict(
+        json_schema_extra={
             "$id": SCHEMA_URI,
             "$schema": SCHEMA_DRAFT,
             "title": "`pixi.toml` manifest file",
@@ -787,8 +788,9 @@ class BaseManifest(StrictBaseModel):
                 {"required": ["package"]},
             ],
         }
+    )
 
-    schema_: str | None = Field(
+    schema_: str | None = Field(  # pyright: ignore[reportCallIssue, reportUnknownVariableType]
         SCHEMA_URI,
         alias="$schema",
         title="Schema",
@@ -805,7 +807,6 @@ class BaseManifest(StrictBaseModel):
     pypi_dependencies: dict[PyPIPackageName, PyPIRequirement] | None = Field(
         None, description="The PyPI dependencies"
     )
-    pypi_options: PyPIOptions | None = Field(None, description="Options related to PyPI indexes")
     tasks: dict[TaskName, TaskInlineTable | list[DependsOn] | NonEmptyStr] | None = Field(
         None, description="The tasks of the project"
     )
@@ -827,7 +828,7 @@ class BaseManifest(StrictBaseModel):
         description="The targets of the project",
         examples=[{"linux": {"dependencies": {"python": "3.8"}}}],
     )
-    tool: dict[str, Any] = Field(
+    tool: dict[str, Any] | None = Field(
         None, description="Third-party tool configurations, ignored by pixi"
     )
     pypi_options: PyPIOptions | None = Field(
@@ -844,7 +845,7 @@ class BaseManifest(StrictBaseModel):
 class SchemaJsonEncoder(json.JSONEncoder):
     """A custom schema encoder for normalizing schema to be used with TOML files."""
 
-    HEADER_ORDER = [
+    HEADER_ORDER: list[str] = [
         "$schema",
         "$id",
         "$ref",
@@ -872,35 +873,36 @@ class SchemaJsonEncoder(json.JSONEncoder):
         "multipleOf",
         "pattern",
     ]
-    FOOTER_ORDER = [
+    FOOTER_ORDER: list[str] = [
         "examples",
         "$defs",
     ]
-    SORT_NESTED = [
+    SORT_NESTED: list[str] = [
         "items",
     ]
-    SORT_NESTED_OBJ = [
+    SORT_NESTED_OBJ: list[str] = [
         "properties",
         "$defs",
     ]
-    SORT_NESTED_MAYBE_OBJ = [
+    SORT_NESTED_MAYBE_OBJ: list[str] = [
         "additionalProperties",
     ]
-    SORT_NESTED_OBJ_OBJ = [
+    SORT_NESTED_OBJ_OBJ: list[str] = [
         "patternProperties",
     ]
-    SORT_NESTED_ARR = [
+    SORT_NESTED_ARR: list[str] = [
         "anyOf",
         "allOf",
         "oneOf",
     ]
 
-    def encode(self, obj):
+    @override
+    def encode(self, o: object):
         """Overload the default ``encode`` behavior."""
-        if isinstance(obj, dict):
-            obj = self.normalize_schema(deepcopy(obj))
+        if isinstance(o, dict):
+            o = self.normalize_schema(deepcopy(o))  # pyright: ignore[reportUnknownArgumentType]
 
-        return super().encode(obj)
+        return super().encode(o)
 
     def normalize_schema(self, obj: dict[str, Any]) -> dict[str, Any]:
         """Recursively normalize and apply an arbitrary sort order to a schema."""
@@ -967,7 +969,7 @@ class SchemaJsonEncoder(json.JSONEncoder):
         if key not in obj or not isinstance(obj[key], dict):
             return obj
         obj[key] = {
-            k: self.normalize_schema(v) if isinstance(v, dict) else v
+            k: self.normalize_schema(v) if isinstance(v, dict) else v  # pyright: ignore[reportUnknownArgumentType]
             for k, v in sorted(obj[key].items(), key=lambda kv: kv[0])
         }
         return obj
