@@ -1,16 +1,15 @@
 import os
 import platform
 import subprocess
-from contextlib import contextmanager
+import sys
+from collections.abc import Sequence
 from enum import IntEnum
 from pathlib import Path
-import sys
-from collections.abc import Generator, Sequence
 from typing import override
 
 from rattler import Platform
 
-PIXI_VERSION = "0.55.0"
+PIXI_VERSION = "0.56.0"
 
 
 ALL_PLATFORMS = '["linux-64", "osx-64", "osx-arm64", "win-64", "linux-ppc64le", "linux-aarch64"]'
@@ -162,16 +161,6 @@ def get_manifest(directory: Path) -> Path:
         raise ValueError("Neither pixi.toml nor pyproject.toml found")
 
 
-@contextmanager
-def cwd(path: str | Path) -> Generator[None, None, None]:
-    oldpwd = os.getcwd()
-    os.chdir(path)
-    try:
-        yield
-    finally:
-        os.chdir(oldpwd)
-
-
 def run_and_get_env(pixi: Path, *args: str, env_var: str) -> tuple[str | None, Output]:
     if sys.platform.startswith("win"):
         cmd = [str(pixi), "exec", *args, "--", "cmd", "/c", f"echo %{env_var}%"]
